<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ko">
<context>
    <name>AddPrinterTask</name>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="551"/>
        <source>URI and driver do not match.</source>
        <translation>URI 및 드라이버가 일치하지 않습니다.</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="553"/>
        <source>Install hplip first and restart the app to install the driver again.</source>
        <translation>hplip를 먼저 설치하고, 앱을 다시 시작하여 드라이버를 다시 설치합니다.</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="561"/>
        <source>Please select an hplip driver and try again.</source>
        <translation>hplip 드라이버를 선택하고 다시 시도하십시오.</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="574"/>
        <source>URI can&apos;t be empty</source>
        <translation>URI는 비워 둘 수 없음</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="581"/>
        <source> not found</source>
        <translation>찾을 수 없음</translation>
    </message>
</context>
<context>
    <name>CheckAttributes</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="305"/>
        <source>Check printer settings</source>
        <translation>프린터 설정 확인</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="314"/>
        <source>Checking printer settings...</source>
        <translation>프린터 설정 확인 중...</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="317"/>
        <source>Success</source>
        <translation>성공</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="327"/>
        <source>Failed to get printer attributes, error: </source>
        <translation>프린터 특성을 가져오지 못함, 오류: </translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="335"/>
        <source>%1 is disabled</source>
        <translation>%1이 비활성화됨</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="344"/>
        <source>is not accepting jobs</source>
        <translation>작업을 수락하지 않음</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="349"/>
        <source>Printer settings are ok</source>
        <translation>프린터 설정이 정상입니다</translation>
    </message>
</context>
<context>
    <name>CheckConnected</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="211"/>
        <source>Check printer connection</source>
        <translation>프린터 연결 확인</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="223"/>
        <source>Checking printer connection...</source>
        <translation>프린터 연결 확인 중...</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="226"/>
        <source>Success</source>
        <translation>성공</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="263"/>
        <source>Cannot connect to the printer, error: %1</source>
        <translation>프린터에 연결할 수 없음, 오류: %1</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="271"/>
        <source> is not connected, URI: </source>
        <translation> 연결되지 않은 URI: </translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="280"/>
        <source>%1 does not exist</source>
        <translation>%1이 존재하지 않음</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="288"/>
        <source>Cannot connect to the printer</source>
        <translation>프린터에 연결할 수 없음</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="294"/>
        <source>The connection is valid</source>
        <translation>연결이 유효합니다</translation>
    </message>
</context>
<context>
    <name>CheckCupsServer</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="109"/>
        <source>Check CUPS server</source>
        <translation>CUPS 서버 확인</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="115"/>
        <source>Checking CUPS server...</source>
        <translation>CUPS 서버 확인중...</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="117"/>
        <source>CUPS server is invalid</source>
        <translation>CUPS 서버가 잘못되었습니다</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="122"/>
        <source>CUPS server is valid</source>
        <translation>CUPS 서버가 유효합니다</translation>
    </message>
</context>
<context>
    <name>CheckDriver</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="140"/>
        <source>Checking driver...</source>
        <translation>드라이버 확인 중...</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="143"/>
        <source>Success</source>
        <translation>성공</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="151"/>
        <source>PPD file %1 not found</source>
        <translation>PPD 파일 %1을 찾을 수 없습니다</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="161"/>
        <source>The driver is damaged</source>
        <translation>드라이버가 손상되었습니다</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="177"/>
        <source>Driver filter %1 not found</source>
        <translation>드라이버 필터 %1을 찾을 수 없습니다</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="189"/>
        <source>%1 is not installed, cannot print now</source>
        <translation>%1이 설치되어 있지 않고 지금 인쇄 할 수 없습니다</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="195"/>
        <source>Driver is valid</source>
        <translation>드라이버가 유효합니다</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="201"/>
        <source>Check driver</source>
        <translation>드라이버 확인</translation>
    </message>
</context>
<context>
    <name>DPrinterSupplyShowDlg</name>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="166"/>
        <source>Low level</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="196"/>
        <source>Unknown</source>
        <translation>알 수 없음</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="261"/>
        <source>Ink/Toner Status</source>
        <translation>잉크/토너 상태</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="268"/>
        <source>Unknown amount</source>
        <translation>알 수 없는 양</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="276"/>
        <source>Unable to get the remaining amount</source>
        <translation>남아있는 총량을 가져올 수 없습니다</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="312"/>
        <source>The amounts are estimated, last updated at %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="325"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>확인</translation>
    </message>
</context>
<context>
    <name>DPrinterTanslator</name>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="33"/>
        <source>Color</source>
        <translation>색상</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="34"/>
        <location filename="../util/dprintertanslator.cpp" line="35"/>
        <source>Grayscale</source>
        <translation>그레이스케일</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="38"/>
        <location filename="../util/dprintertanslator.cpp" line="69"/>
        <location filename="../util/dprintertanslator.cpp" line="86"/>
        <location filename="../util/dprintertanslator.cpp" line="107"/>
        <location filename="../util/dprintertanslator.cpp" line="126"/>
        <location filename="../util/dprintertanslator.cpp" line="135"/>
        <source>None</source>
        <translation>없음</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="39"/>
        <location filename="../util/dprintertanslator.cpp" line="49"/>
        <source>Draft</source>
        <translation>초안</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="40"/>
        <location filename="../util/dprintertanslator.cpp" line="120"/>
        <source>Normal</source>
        <translation>보통</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="43"/>
        <location filename="../util/dprintertanslator.cpp" line="44"/>
        <location filename="../util/dprintertanslator.cpp" line="47"/>
        <source>Print Quality</source>
        <translation>인쇄 품질</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="48"/>
        <location filename="../util/dprintertanslator.cpp" line="60"/>
        <source>Manual</source>
        <translation>수동</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="52"/>
        <location filename="../util/dprintertanslator.cpp" line="53"/>
        <location filename="../util/dprintertanslator.cpp" line="54"/>
        <source>Paper Source</source>
        <translation>용지 공급</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="55"/>
        <location filename="../util/dprintertanslator.cpp" line="56"/>
        <source>Auto-Select</source>
        <translation>자동-선택</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="57"/>
        <location filename="../util/dprintertanslator.cpp" line="58"/>
        <source>Manual Feeder</source>
        <translation>수동 급지대</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="59"/>
        <location filename="../util/dprintertanslator.cpp" line="73"/>
        <source>Auto</source>
        <translation>자동</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="61"/>
        <source>Drawer 1</source>
        <translation>드로우도구 1</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="62"/>
        <source>Drawer 2</source>
        <translation>드로우도구 2</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="63"/>
        <source>Drawer 3</source>
        <translation>드로우도구 3</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="64"/>
        <source>Drawer 4</source>
        <translation>드로우도구 4</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="65"/>
        <source>Drawer 5</source>
        <translation>드로우도구 5</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="66"/>
        <source>Envelope Feeder</source>
        <translation>봉투 급지대</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="67"/>
        <source>Tray1</source>
        <translation>트레이 1</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="68"/>
        <source>Unknown</source>
        <translation>알 수 없음</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="72"/>
        <source>MediaType</source>
        <translation>미디어 유형</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="74"/>
        <source>Plain Paper</source>
        <translation>일반 용지</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="75"/>
        <source>Recycled Paper</source>
        <translation>재활용 용지</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="76"/>
        <source>Color Paper</source>
        <translation>색상 용지</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="77"/>
        <source>Bond Paper</source>
        <translation>본드 용지</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="78"/>
        <source>Heavy Paper 1</source>
        <translation>두꺼운 용지 1</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="79"/>
        <source>Heavy Paper 2</source>
        <translation>두꺼운 용지 2</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="80"/>
        <source>Heavy Paper 3</source>
        <translation>두꺼운 용지 3</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="81"/>
        <location filename="../util/dprintertanslator.cpp" line="82"/>
        <source>OHP</source>
        <translation>OHP</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="83"/>
        <source>Labels</source>
        <translation>라벨</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="84"/>
        <source>Envelope</source>
        <translation>봉투</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="85"/>
        <source>Photo Paper</source>
        <translation>사진 용지</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="89"/>
        <location filename="../util/dprintertanslator.cpp" line="90"/>
        <location filename="../util/dprintertanslator.cpp" line="91"/>
        <source>PageSize</source>
        <translation>용지 크기</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="92"/>
        <source>Custom</source>
        <translation>사용자지정</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="95"/>
        <location filename="../util/dprintertanslator.cpp" line="96"/>
        <location filename="../util/dprintertanslator.cpp" line="97"/>
        <source>Duplex</source>
        <translation>양면</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="98"/>
        <source>DuplexTumble</source>
        <translation>양면(짧은 쪽으로 넘김)</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="99"/>
        <source>DuplexNoTumble</source>
        <translation>양면(긴 쪽으로 넘김)</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="100"/>
        <source>ON (Long-edged Binding)</source>
        <translation>켜기 (긴 가장자리)</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="101"/>
        <source>ON (Short-edged Binding)</source>
        <translation>켜기 (짧은 가장자리)</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="102"/>
        <location filename="../util/dprintertanslator.cpp" line="103"/>
        <source>OFF</source>
        <translation>끄기</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="106"/>
        <location filename="../util/dprintertanslator.cpp" line="110"/>
        <source>Binding Edge</source>
        <translation>바인딩 에지</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="108"/>
        <source>Left</source>
        <translation>왼쪽</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="109"/>
        <source>Top</source>
        <translation>상단</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="113"/>
        <source>Portrait (no rotation)</source>
        <translation>세로방향 (회전 없음)</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="114"/>
        <source>Landscape (90 degrees)</source>
        <translation>가로방향 (90도)</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="115"/>
        <source>Reverse landscape (270 degrees)</source>
        <translation>역가로방향 (270도)</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="116"/>
        <source>Reverse portrait (180 degrees)</source>
        <translation>역세로방향 (180도)</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="117"/>
        <source>Auto Rotation</source>
        <translation>자동 회전</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="121"/>
        <source>Reverse</source>
        <translation>역방향</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="124"/>
        <location filename="../util/dprintertanslator.cpp" line="125"/>
        <source>Staple Location</source>
        <translation>제본 위치</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="127"/>
        <source>Bind</source>
        <translation>제본</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="128"/>
        <source>Bind (none)</source>
        <translation>제본 (없음)</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="129"/>
        <source>Bind (bottom)</source>
        <translation>제본 (아래쪽)</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="130"/>
        <source>Bind (left)</source>
        <translation>제본 (왼쪽)</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="131"/>
        <source>Bind (right)</source>
        <translation>제본 (오른쪽)</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="132"/>
        <source>Bind (top)</source>
        <translation>제본 (위쪽)</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="136"/>
        <location filename="../util/dprintertanslator.cpp" line="137"/>
        <source>Resolution</source>
        <translation>해상도</translation>
    </message>
</context>
<context>
    <name>DPrintersShowWindow</name>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="91"/>
        <source>Settings</source>
        <translation>설정</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="99"/>
        <source>Printers</source>
        <translation>프린터</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="104"/>
        <source>Add printer</source>
        <translation>프린터 추가</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="107"/>
        <source>Delete printer</source>
        <translation>프린터 삭제</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="142"/>
        <source>Rename</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="143"/>
        <source>Shared</source>
        <translation>공유됨</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="146"/>
        <source>Enabled</source>
        <translation>활성화됨</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="149"/>
        <source>Accept jobs</source>
        <translation>작업을 수락합니다</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="153"/>
        <source>Set as default</source>
        <translation>기본값으로 설정</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="166"/>
        <source>No Printers</source>
        <translation>프린터 없음</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="193"/>
        <source>Location:</source>
        <translation>위치:</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="198"/>
        <source>Model:</source>
        <translation>모델:</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="201"/>
        <source>Status:</source>
        <translation>상태:</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="237"/>
        <source>Properties</source>
        <translation>속성</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="665"/>
        <location filename="../ui/dprintersshowwindow.cpp" line="667"/>
        <source>Print Queue</source>
        <translation>인쇄 대기열</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="670"/>
        <location filename="../ui/dprintersshowwindow.cpp" line="672"/>
        <source>Print Test Page</source>
        <translation>테스트 페이지 인쇄</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="274"/>
        <source>Supplies</source>
        <translation>소모품</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="310"/>
        <source>No printer configured</source>
        <translation>구성된 프린터 없음</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="316"/>
        <source>Click + to add printers</source>
        <translation>+를 클릭하여 프린터 추가</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="365"/>
        <source>As print jobs are in process, you cannot rename the printer now, please try later</source>
        <translation>인쇄 작업이 진행 중이므로 프린터 이름을 바꿀 수 없습니다, 나중에 시도하십시오.</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="369"/>
        <location filename="../ui/dprintersshowwindow.cpp" line="428"/>
        <location filename="../ui/dprintersshowwindow.cpp" line="786"/>
        <source>OK</source>
        <translation>확인</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="425"/>
        <source>CUPS server is not running, and can’t manage printers.</source>
        <translation>CUPS 서버가 실행중이 아니며 프린터를 관리할 수 없습니다.</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="692"/>
        <source>Idle</source>
        <translation>Idle</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="694"/>
        <source>Printing</source>
        <translation>인쇄중</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="696"/>
        <source>Disabled</source>
        <translation>비활성화됨</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="744"/>
        <source>Are you sure you want to delete the printer &quot;%1&quot; ?</source>
        <translation>프린터 &quot;%1&quot;를 삭제하시겠습니까?</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="750"/>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="782"/>
        <source>The name already exists</source>
        <translation>이름이 이미 있습니다</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="801"/>
        <source>You will not be able to reprint the completed jobs if continue. Are you sure you want to rename the printer?</source>
        <translation>계속하면 완료된 작업을 다시 인쇄할 수 없습니다. 프린터 이름을 바꾸시겠습니까?</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="806"/>
        <source>Confirm</source>
        <translation>확인</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="865"/>
        <source>The driver is damaged, please install it again.</source>
        <translation>드라이버가 손상되었습니다. 다시 설치하십시오.</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="868"/>
        <source>Install Driver</source>
        <translation>드라이버 설치</translation>
    </message>
</context>
<context>
    <name>DPropertySetDlg</name>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="261"/>
        <source>Print Properties</source>
        <translation>프린터 속성</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="262"/>
        <source>Driver</source>
        <translation>드라이버</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="263"/>
        <source>URI</source>
        <translation>URI</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="264"/>
        <source>Location</source>
        <translation>위치</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="265"/>
        <source>Description</source>
        <translation>설명</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="266"/>
        <source>Color Mode</source>
        <translation>색상 모드</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="267"/>
        <source>Orientation</source>
        <translation>방향</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="268"/>
        <source>Page Order</source>
        <translation>용지 순서</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="703"/>
        <source>Options conflict!</source>
        <translation>옵션 충돌!</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="706"/>
        <source>Please resolve the conflict first, and then save the changes.</source>
        <translation>먼저 충돌을 해결한 다음 변경 내용을 저장하십시오.</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="725"/>
        <source>Conflict:</source>
        <translation>충돌 :</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="736"/>
        <location filename="../ui/dpropertysetdlg.cpp" line="1234"/>
        <source>OK</source>
        <translation>확인</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="1233"/>
        <source>Invalid URI</source>
        <translation>잘못된 URI</translation>
    </message>
</context>
<context>
    <name>DriverManager</name>
    <message>
        <location filename="../../Common/vendor/zdrivermanager.cpp" line="1031"/>
        <source>EveryWhere driver</source>
        <translation>EveryWhere 드라이버</translation>
    </message>
</context>
<context>
    <name>InstallDriver</name>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="373"/>
        <source>Failed to find the driver solution: %1, error: %2</source>
        <translation>드라이버 해결 방법을 찾지 못함: %1, 오류: %2</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="384"/>
        <source>The solution is invalid</source>
        <translation>해결 방법이 잘못되었습니다.</translation>
    </message>
</context>
<context>
    <name>InstallDriverWindow</name>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="103"/>
        <location filename="../ui/installdriverwindow.cpp" line="107"/>
        <source>Select a driver from</source>
        <translation>다음에서 드라이버를 선택하십시오</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="113"/>
        <location filename="../ui/installdriverwindow.cpp" line="116"/>
        <source>Local driver</source>
        <translation>로컬 드라이버</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="118"/>
        <location filename="../ui/installdriverwindow.cpp" line="121"/>
        <source>Local PPD file</source>
        <translation>로컬 PPD 파일</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="123"/>
        <location filename="../ui/installdriverwindow.cpp" line="126"/>
        <source>Search for a driver</source>
        <translation>드라이버 검색</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="146"/>
        <location filename="../ui/installdriverwindow.cpp" line="464"/>
        <source>Choose a local driver</source>
        <translation>로컬 드라이버 선택</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="150"/>
        <source>Vendor</source>
        <translation>제조업체</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="164"/>
        <source>Model</source>
        <translation>모델:</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="177"/>
        <location filename="../ui/installdriverwindow.cpp" line="259"/>
        <source>Driver</source>
        <translation>드라이버</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="242"/>
        <source>Vendor and Model</source>
        <translation>제조업체 및 모델</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="244"/>
        <source>Enter a complete vendor and model (Only letters, numbers and whitespaces)</source>
        <translation>완전한 제조업체 및 모델 입력 (문자, 숫자 및 공백만 해당)</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="247"/>
        <source>Search</source>
        <comment>button</comment>
        <translation>검색</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="296"/>
        <source>Install Driver</source>
        <comment>button</comment>
        <translation>드라이버 설치</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="446"/>
        <location filename="../ui/installdriverwindow.cpp" line="556"/>
        <source>Reselect</source>
        <translation>재선택</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="472"/>
        <location filename="../ui/installdriverwindow.cpp" line="553"/>
        <source>Select a PPD file</source>
        <translation>PPD 파일 선택</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="481"/>
        <source>Search for printer driver</source>
        <translation>프린터 드라이버 검색</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="535"/>
        <source>(recommended)</source>
        <translation>(권장)</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="707"/>
        <source> (recommended)</source>
        <translation> (권장)</translation>
    </message>
</context>
<context>
    <name>InstallInterface</name>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="251"/>
        <source>is invalid</source>
        <translation>올바르지 않습니다</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="280"/>
        <source>Failed to install the driver by calling dbus interface</source>
        <translation>dbus 인터페이스를 호출하여 드라이버를 설치하지 못했습니다</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="325"/>
        <source>Failed to install %1</source>
        <translation>%1을 설치하지 못했습니다</translation>
    </message>
</context>
<context>
    <name>InstallPrinterWindow</name>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="87"/>
        <location filename="../ui/installprinterwindow.cpp" line="163"/>
        <source>Installing driver...</source>
        <translation>드라이버 설치 중...</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="97"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>취소</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="100"/>
        <location filename="../ui/installprinterwindow.cpp" line="186"/>
        <location filename="../ui/installprinterwindow.cpp" line="203"/>
        <source>View Printer</source>
        <comment>button</comment>
        <translation>프린터 보기</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="102"/>
        <location filename="../ui/installprinterwindow.cpp" line="188"/>
        <location filename="../ui/installprinterwindow.cpp" line="205"/>
        <source>Print Test Page</source>
        <comment>button</comment>
        <translation>테스트 페이지 인쇄</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="175"/>
        <source>Successfully installed </source>
        <translation>성공적으로 설치됨</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="181"/>
        <location filename="../ui/installprinterwindow.cpp" line="199"/>
        <source>You have successfully added the printer. Print a test page to check if it works properly.</source>
        <translation>프린터를 성공적으로 추가했습니다. 테스트 페이지를 인쇄하여 제대로 작동하는지 확인합니다.</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="193"/>
        <source>Printing test page...</source>
        <translation>테스트 페이지 인쇄 중...</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="210"/>
        <source>Did you print the test page successfully?</source>
        <translation>테스트 페이지를 성공적으로 인쇄했습니까?</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="216"/>
        <source>If succeeded, click Yes; if failed, click No</source>
        <translation>성공하면 예를, 실패하면 아니오를 클릭하십시오</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="219"/>
        <source>No</source>
        <translation>아니요</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="221"/>
        <source>Yes</source>
        <translation>예</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="226"/>
        <location filename="../ui/installprinterwindow.cpp" line="246"/>
        <source>Print failed</source>
        <translation>인쇄 실패</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="232"/>
        <source>Click Reinstall to install the printer driver again, or click Troubleshoot to start troubleshooting.</source>
        <translation>재설치를 클릭하여 프린터 드라이버를 다시 설치하거나 문제 해결을 클릭하여 문제 해결을 시작합니다.</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="235"/>
        <location filename="../ui/installprinterwindow.cpp" line="256"/>
        <source>Reinstall</source>
        <comment>button</comment>
        <translation>재설치</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="237"/>
        <location filename="../ui/installprinterwindow.cpp" line="258"/>
        <source>Troubleshoot</source>
        <comment>button</comment>
        <translation>문제 해결</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="244"/>
        <source>Installation failed</source>
        <translation>설치 실패</translation>
    </message>
</context>
<context>
    <name>JobListView</name>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="252"/>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="253"/>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="254"/>
        <source>Pause</source>
        <translation>일시 중지</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="255"/>
        <source>Resume</source>
        <translation>재시작</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="256"/>
        <source>Print first</source>
        <translation>먼저 인쇄</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="257"/>
        <source>Reprint</source>
        <translation>재인쇄</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="259"/>
        <source>No print jobs</source>
        <translation>인쇄 작업이 없습니다</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="405"/>
        <source>Are you sure you want to delete this job?</source>
        <translation>이 작업을 삭제 하시겠습니까?</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="411"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>취소</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="412"/>
        <source>Delete</source>
        <comment>button</comment>
        <translation>삭제</translation>
    </message>
</context>
<context>
    <name>JobManager</name>
    <message>
        <location filename="../../Common/zjobmanager.cpp" line="307"/>
        <source> not found</source>
        <translation>찾을 수 없음</translation>
    </message>
</context>
<context>
    <name>JobManagerWindow</name>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="1099"/>
        <source>Refresh</source>
        <translation>새로고침</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="1105"/>
        <source>All</source>
        <translation>모두</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="1106"/>
        <source>Print Queue</source>
        <translation>인쇄 대기열</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="1107"/>
        <source>Completed</source>
        <translation>완료됨</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="1176"/>
        <source> failed</source>
        <translation>실패</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="1197"/>
        <source>%1 jobs</source>
        <translation>%1개의 작업</translation>
    </message>
</context>
<context>
    <name>JobsDataModel</name>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="713"/>
        <source>Job</source>
        <translation>작업</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="715"/>
        <source>User</source>
        <translation>사용자</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="717"/>
        <source>Document</source>
        <translation>문서</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="719"/>
        <source>Printer</source>
        <translation>프린터</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="721"/>
        <source>Size</source>
        <translation>크기</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="723"/>
        <source>Time submitted</source>
        <translation>제출된 시간</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="725"/>
        <source>Status</source>
        <translation>상태</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="727"/>
        <source>Action</source>
        <translation>동작</translation>
    </message>
</context>
<context>
    <name>PermissionsWindow</name>
    <message>
        <location filename="../ui/permissionswindow.cpp" line="48"/>
        <source>Connect to %1 to find a printer</source>
        <translation>%1에 연결하여 프린터를 찾습니다</translation>
    </message>
    <message>
        <location filename="../ui/permissionswindow.cpp" line="74"/>
        <source>Username</source>
        <translation>사용자 이름</translation>
    </message>
    <message>
        <location filename="../ui/permissionswindow.cpp" line="76"/>
        <source>Group</source>
        <translation>그룹</translation>
    </message>
    <message>
        <location filename="../ui/permissionswindow.cpp" line="78"/>
        <source>Password</source>
        <translation>비밀번호</translation>
    </message>
    <message>
        <location filename="../ui/permissionswindow.cpp" line="92"/>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <location filename="../ui/permissionswindow.cpp" line="93"/>
        <source>Connect</source>
        <translation>연결하기</translation>
    </message>
</context>
<context>
    <name>PrinterApplication</name>
    <message>
        <location filename="../ui/printerapplication.cpp" line="104"/>
        <source>Print Manager</source>
        <translation>인쇄 관리자</translation>
    </message>
    <message>
        <location filename="../ui/printerapplication.cpp" line="105"/>
        <source>Print Manager is a printer management tool, which supports adding and removing printers, managing print jobs and so on.</source>
        <translation>인쇄 관리자는 프린터 추가 및 제거, 인쇄 작업 관리 등을 지원하는 프린터 관리 도구입니다.</translation>
    </message>
</context>
<context>
    <name>PrinterSearchWindow</name>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="88"/>
        <location filename="../ui/printersearchwindow.cpp" line="91"/>
        <source>Discover printer</source>
        <translation>프린터 검색</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="94"/>
        <location filename="../ui/printersearchwindow.cpp" line="97"/>
        <source>Find printer</source>
        <translation>프린터 찾기</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="99"/>
        <location filename="../ui/printersearchwindow.cpp" line="102"/>
        <source>Enter URI</source>
        <translation>URI 입력</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="125"/>
        <source>Select a printer</source>
        <translation>프린터 선택</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="132"/>
        <source>Refresh</source>
        <translation>새로고침</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="155"/>
        <location filename="../ui/printersearchwindow.cpp" line="268"/>
        <source>No printers found</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="202"/>
        <source>Install Driver</source>
        <translation>드라이버 설치</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="233"/>
        <source>Address</source>
        <translation>주소</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="236"/>
        <source>Enter an address</source>
        <translation>주소 입력</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="238"/>
        <source>Find</source>
        <comment>button</comment>
        <translation>찾기</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="346"/>
        <source>URI</source>
        <translation>URI</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="351"/>
        <source>Enter device URI</source>
        <translation>장치 URI 입력</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="376"/>
        <source>Examples:</source>
        <translation>예제:</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="698"/>
        <source>OK</source>
        <translation>확인</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="784"/>
        <source> (recommended)</source>
        <translation> (권장)</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="794"/>
        <source>The driver was found</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="795"/>
        <source>Connect to the network and try again</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="797"/>
        <source>Cannot find the driver</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="798"/>
        <source>Please try to install it manually or search its official website</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="808"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>확인</translation>
    </message>
</context>
<context>
    <name>PrinterTestJob</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="370"/>
        <source>Check test page printing</source>
        <translation>테스트 페이지 인쇄 확인</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="424"/>
        <source>Printing test page...</source>
        <translation>테스트 페이지 인쇄 중...</translation>
    </message>
</context>
<context>
    <name>PrinterTestPageDialog</name>
    <message>
        <location filename="../ui/printertestpagedialog.cpp" line="61"/>
        <source>OK</source>
        <translation>확인</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="226"/>
        <source>Black</source>
        <translation>검정색</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="227"/>
        <source>Blue</source>
        <translation>파란색</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="228"/>
        <source>Brown</source>
        <translation>갈색</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="229"/>
        <source>Cyan</source>
        <translation>청록색</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="230"/>
        <source>Dark-gray</source>
        <translation>짙은_회색</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="231"/>
        <source>Dark gray</source>
        <translation>짙은 회색</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="232"/>
        <source>Dark-yellow</source>
        <translation>진한_노란색</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="233"/>
        <source>Dark yellow</source>
        <translation>진한 노란색</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="234"/>
        <source>Gold</source>
        <translation>금색</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="235"/>
        <source>Gray</source>
        <translation>회색</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="236"/>
        <source>Green</source>
        <translation>녹색</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="237"/>
        <source>Light-black</source>
        <translation>밝은_검정색</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="238"/>
        <source>Light black</source>
        <translation>밝은 검정색</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="239"/>
        <source>Light-cyan</source>
        <translation>밝은_청록색</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="240"/>
        <source>Light cyan</source>
        <translation>밝은 청록색</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="241"/>
        <source>Light-gray</source>
        <translation>밝은_회색</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="242"/>
        <source>Light gray</source>
        <translation>밝은 회색</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="243"/>
        <source>Light-magenta</source>
        <translation>밝은_자홍색</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="244"/>
        <source>Light magenta</source>
        <translation>밝은 자홍색</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="245"/>
        <source>Magenta</source>
        <translation>자홍색</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="246"/>
        <source>Orange</source>
        <translation>주황색</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="247"/>
        <source>Red</source>
        <translation>빨간색</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="248"/>
        <source>Silver</source>
        <translation>은색</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="249"/>
        <source>White</source>
        <translation>흰색</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="250"/>
        <source>Yellow</source>
        <translation>노란색</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="251"/>
        <source>Waste</source>
        <translation>소모</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="108"/>
        <source>1 min ago</source>
        <translation>1분 전</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="111"/>
        <source>%1 mins ago</source>
        <translation>%1분 전</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="115"/>
        <source>1 hr ago</source>
        <translation>1시간 전</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="117"/>
        <source>%1 hrs ago</source>
        <translation>%1시간 전</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="122"/>
        <source>Yesterday</source>
        <translation>어제</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="124"/>
        <source>%1 days ago</source>
        <translation>%1일 전</translation>
    </message>
    <message>
        <location filename="../ui/printerapplication.cpp" line="113"/>
        <source>Direct-attached Device</source>
        <translation>직접 연결된 장치</translation>
    </message>
    <message>
        <location filename="../ui/printerapplication.cpp" line="114"/>
        <source>File</source>
        <translation>파일</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="616"/>
        <source>(use %1 protocol)</source>
        <translation>(%1 프로토콜 사용)</translation>
    </message>
    <message>
        <location filename="../ui/uisourcestring.h" line="26"/>
        <source>Select a driver</source>
        <translation>드라이버 선택</translation>
    </message>
    <message>
        <location filename="../ui/uisourcestring.h" line="32"/>
        <source>Driver</source>
        <translation>드라이버</translation>
    </message>
    <message>
        <location filename="../ui/uisourcestring.h" line="33"/>
        <source>Next</source>
        <comment>button</comment>
        <translation>다음</translation>
    </message>
    <message>
        <location filename="../ui/uisourcestring.h" line="34"/>
        <source>Install Driver</source>
        <comment>button</comment>
        <translation>드라이버 설치</translation>
    </message>
    <message>
        <location filename="../ui/uisourcestring.h" line="36"/>
        <source>Drag a PPD file here 
 or</source>
        <translation>PPD 파일을 여기로 끌어다 놓으십시오
또는</translation>
    </message>
    <message>
        <location filename="../ui/uisourcestring.h" line="37"/>
        <source>Select a PPD file</source>
        <comment>button</comment>
        <translation>PPD 파일 선택</translation>
    </message>
    <message>
        <location filename="../ui/uisourcestring.h" line="39"/>
        <source>Troubleshoot</source>
        <translation>문제 해결</translation>
    </message>
    <message>
        <location filename="../ui/uisourcestring.h" line="40"/>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <location filename="../ui/uisourcestring.h" line="43"/>
        <source>For more drivers, please refer to our official website: </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../util/ddestination.cpp" line="201"/>
        <source>Idle</source>
        <translation>Idle</translation>
    </message>
    <message>
        <location filename="../util/ddestination.cpp" line="204"/>
        <source>Printing</source>
        <translation>인쇄중</translation>
    </message>
    <message>
        <location filename="../util/ddestination.cpp" line="207"/>
        <source>Disabled</source>
        <translation>비활성화됨</translation>
    </message>
    <message>
        <location filename="../util/dprinter.cpp" line="285"/>
        <source>(recommended)</source>
        <translation>(권장)</translation>
    </message>
    <message>
        <location filename="../ui/dprinterpropertytemplate.h" line="33"/>
        <source>Preferences</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../Common/common.cpp" line="154"/>
        <source>%1 not found, please ask the administrator for help, or enter the printer IP address in URI of Properties.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RenamePrinterWindow</name>
    <message>
        <location filename="../ui/renameprinterwindow.cpp" line="84"/>
        <source>Rename Printer</source>
        <translation>프린터 이름변경</translation>
    </message>
    <message>
        <location filename="../ui/renameprinterwindow.cpp" line="91"/>
        <source>Name</source>
        <translation>이름</translation>
    </message>
    <message>
        <location filename="../ui/renameprinterwindow.cpp" line="93"/>
        <source>Location</source>
        <translation>위치</translation>
    </message>
    <message>
        <location filename="../ui/renameprinterwindow.cpp" line="95"/>
        <source>Description</source>
        <translation>설명</translation>
    </message>
    <message>
        <location filename="../ui/renameprinterwindow.cpp" line="106"/>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <location filename="../ui/renameprinterwindow.cpp" line="107"/>
        <source>Confirm</source>
        <translation>확인</translation>
    </message>
</context>
<context>
    <name>ServerSettingsWindow</name>
    <message>
        <location filename="../ui/dprintersshowwindow.h" line="92"/>
        <source>Basic Server Settings</source>
        <translation>기본 서버 설정</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.h" line="101"/>
        <source>Publish shared printers connected to this system</source>
        <translation>이 시스템에 연결된 공유 프린터 게시</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.h" line="103"/>
        <source>Allow printing from the Internet</source>
        <translation>인터넷에서 인쇄 허용</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.h" line="105"/>
        <source>Allow remote administration</source>
        <translation>원격 관리 허용</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.h" line="107"/>
        <source>Save debugging information for troubleshooting</source>
        <translation>문제 해결을 위해 디버깅 정보 저장</translation>
    </message>
</context>
<context>
    <name>TroubleShootDialog</name>
    <message>
        <location filename="../ui/troubleshootdialog.cpp" line="118"/>
        <source>Troubleshoot: </source>
        <translation>문제 해결</translation>
    </message>
    <message>
        <location filename="../ui/troubleshootdialog.cpp" line="145"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>취소</translation>
    </message>
    <message>
        <location filename="../ui/troubleshootdialog.cpp" line="178"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>확인</translation>
    </message>
</context>
</TS>